@@ -1,6 +1,6 @@
 package Package::Stash;
 BEGIN {
-  $Package::Stash::VERSION = '0.07';
+  $Package::Stash::VERSION = '0.08';
 }
 use strict;
 use warnings;
@@ -8,7 +8,6 @@ use warnings;
 
 use Carp qw(confess);
 use Scalar::Util qw(reftype);
-use Symbol;
 
 
 sub new {
@@ -157,32 +156,22 @@ sub get_package_symbol {
 
     my $namespace = $self->namespace;
 
-    if ($opts{vivify} && !exists $namespace->{$name}) {
-        if ($type eq 'ARRAY') {
-            $self->add_package_symbol(
-                $variable,
-                # setting our own arrayref manually loses the magicalness or
-                # something
-                $name eq 'ISA' ? () : ([])
-            );
+    if (!exists $namespace->{$name}) {
+        # assigning to the result of this function like
+        #   @{$stash->get_package_symbol('@ISA')} = @new_ISA
+        # makes the result not visible until the variable is explicitly
+        # accessed... in the case of @ISA, this might never happen
+        # for instance, assigning like that and then calling $obj->isa
+        # will fail. see t/005-isa.t
+        if ($opts{vivify} && $type eq 'ARRAY' && $name ne 'ISA') {
+            $self->add_package_symbol($variable, []);
         }
-        elsif ($type eq 'HASH') {
+        elsif ($opts{vivify} && $type eq 'HASH') {
             $self->add_package_symbol($variable, {});
         }
-        elsif ($type eq 'SCALAR') {
-            $self->add_package_symbol($variable);
-        }
-        elsif ($type eq 'IO') {
-            $self->add_package_symbol($variable, Symbol::geniosym);
-        }
-        elsif ($type eq 'CODE') {
-            # ignoring this case for now, since i don't know what would
-            # be useful to do here (and subs in the stash autovivify in weird
-            # ways too)
-            #$self->add_package_symbol($variable, sub {});
-        }
         else {
-            confess "Unknown type $type in vivication";
+            # FIXME
+            $self->add_package_symbol($variable)
         }
     }
 
@@ -306,7 +295,7 @@ Package::Stash - routines for manipulating stashes
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
